import React, { useEffect } from "react";
import { Outlet, useLocation, useNavigate } from "react-router-dom";
import cx from "classnames";
import { observer } from "mobx-react-lite";
import ArrowDropDownIcon from "@mui/icons-material/ArrowDropDown";
import Add from "@mui/icons-material/Add";
import Avatar from "@mui/material/Avatar";
import { Box, Menu, MenuItem } from "@mui/material";

import globalText from "@/utils/globalText_CN";
import useIndex from "./useIndex";
import { useStores } from "@/store/index";
import Button from "@/components/mui/Button";
import logo from "@/assets/img/logo.svg";
import MyPopover from "@/components/mui/MyPopover";
import TranSferList from "./components/TransferList";

import style from "./index.module.css";
import useGlobalStore from "@/hooks/useGlobalStore";
import { toJS } from "mobx";
import { urlToken } from "@/api/fileserver/raysyncApi";
import UseTusUpload from "@/utils/Upload/tusUpload";
import useMyRequest from "@/hooks/useMyRequest";
import { getDataFileToken } from "@/api/project_api";
import useDeepEffect from "@/hooks/useDeepEffect";

const ConsoleLayout = observer(() => {
  const {
    productAnchorEl,
    utilityAnchorEl,
    productOpen,
    utilityOpen,
    handleProductClick,
    handleUtilityClick,
    handleClose,
  } = useIndex();

  const navigate = useNavigate();
  const location = useLocation();
  const { permissionStore, menuStore } = useStores();

  useEffect(() => {
    permissionStore.setSidebarRouters(location.pathname);
  }, [location, permissionStore]);

  const fileList = toJS(useGlobalStore("fileListStore"));
  const currentProjectStore = toJS(useGlobalStore("currentProjectStore"));
  const { uploadFile } = UseTusUpload({
    fileListStore: fileList,
    currentProjectStore,
  });

  /** 获取文件token请求 */
  const { run: getDataFileTokenRun } = useMyRequest(getDataFileToken, {
    onSuccess: (res: any) => {
      let url =
        "https://fileserver.cloudam.cn/parallelupload/" +
        urlToken(
          res?.data || "",
          currentProjectStore?.currentProjectInfo?.id as string
        );
      fileList?.newFileList?.forEach((item: any) => {
        uploadFile(
          item,
          item?.list,
          url,
          "/",
          (upload: any, filepath: string) => console.log(upload, filepath, 1111)
        );
      });
    },
  });

  useDeepEffect(() => {
    if (fileList?.newFileList?.length) {
      getDataFileTokenRun({
        id: currentProjectStore?.currentProjectInfo.id || "",
      });
    }
  }, [fileList?.newFileList]);

  return (
    <Box>
      <Box className={style.topApp}>
        <Box className={style.topLeftBox}>
          <img src={logo} alt="" className={style.logo} />

          <Button
            text={globalText.console}
            variant={"text"}
            style={{ color: "#565C66" }}
            click={() => navigate("/home")}
          />

          <Box sx={{ display: "flex", alignItems: "center" }}>
            <Button
              text={globalText.product}
              variant={"text"}
              style={{ color: "#565C66" }}
              click={handleProductClick}
              dropValue={productOpen}
              drop={true}
            />

            {/* <ArrowDropDownIcon classes={{
              root: cx({
                [style.ArrowDropDownIconRoot]: true,
                [style.ArrowDropDownIconRootOpen]: Boolean(productOpen)
              })
            }} /> */}

            <Menu
              id="product-menu"
              anchorEl={productAnchorEl}
              open={productOpen}
              onClose={handleClose}
              classes={{
                paper: style.menuPaper,
              }}
              MenuListProps={{
                "aria-labelledby": "product-button",
              }}
            >
              {menuStore.productList.map((item) => {
                return (
                  <MenuItem
                    key={item.path}
                    classes={{
                      root: style.menuItemRoot,
                    }}
                    onClick={() => {
                      navigate(item.path);
                      handleClose();
                    }}
                  >
                    {item.name}
                  </MenuItem>
                );
              })}
            </Menu>
          </Box>
        </Box>

        <Box className={style.topRightBox}>
          <MyPopover
            content={<TranSferList />}
            transformOrigin={{
              vertical: "top",
              horizontal: "right",
            }}
          >
            <Box className={style.topRightItem}>
              <Add />
            </Box>
          </MyPopover>
          <Box className={style.topRightItem}>
            <Box
              sx={{ display: "flex", alignItems: "center" }}
              onClick={handleUtilityClick}
            >
              <Avatar
                sx={{
                  bgcolor: "#1370FF",
                  width: 28,
                  height: 28,
                  fontSize: "14px",
                  cursor: "pointer",
                }}
              >
                H
              </Avatar>
              <ArrowDropDownIcon
                classes={{
                  root: cx({
                    [style.ArrowDropDownIconRoot]: true,
                    [style.ArrowDropDownIconRootOpen]: Boolean(utilityOpen),
                  }),
                }}
              />
            </Box>

            <Menu
              id="utility-menu"
              anchorEl={utilityAnchorEl}
              open={utilityOpen}
              onClose={handleClose}
              MenuListProps={{
                "aria-labelledby": "utility-button",
              }}
            >
              {menuStore.utilityList.map((item) => {
                return (
                  <MenuItem
                    key={item.path}
                    onClick={() => {
                      navigate(item.path);
                      handleClose();
                    }}
                  >
                    {item.name}
                  </MenuItem>
                );
              })}
            </Menu>
          </Box>
        </Box>
      </Box>
      <Box>
        <Outlet></Outlet>
      </Box>
    </Box>
  );
});

export default ConsoleLayout;
